
/*==============================================================================
 *
 * (#)Filter.java
 * created      2003/10/14
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 *==============================================================================
 */

package com.miami.romeo.filter;

import java.awt.*;
import java.awt.event.*;

import javax.swing.*;

import com.miami.romeo.config.*;
import com.miami.romeo.main.*;
import com.miami.romeo.graphics.DialogSeparator;

public class Filter extends JPanel {
  Romeo romeo = null;
  Utils utils = new Utils();

  final static int GAP = 10;

  // JCheckBox driverStatusCheckBox = null;
  // JCheckBox videoCheckBox        = null;
  JCheckBox yearCheckBox         = null;
  JCheckBox lyearCheckBox        = null;
  JCheckBox gyearCheckBox        = null;
  JCheckBox nyearCheckBox        = null;
  JCheckBox eyearCheckBox        = null;
  DefaultListModel yearModel     = null;
  JList yearList                 = null;

  // JCheckBox playersCheckBox      = null;
  // JCheckBox controlsCheckBox     = null;
  JCheckBox manufacturerCheckBox = null;
  JCheckBox driverCheckBox       = null;
  JCheckBox categoryCheckBox     = null;
  JCheckBox screenshotCheckBox   = null;
  JCheckBox flyerCheckBox        = null;
  JCheckBox marqueeCheckBox      = null;
  JCheckBox cabinetCheckBox      = null;
  JCheckBox sampleCheckBox       = null;
  JCheckBox artworkCheckBox      = null;

  JPanel panel                   = null;
  JPanel panel2                  = null;

  // Used cause Filter is an application.
  private static JFrame frame = null;

  public Filter(Romeo romeo) {
    this.romeo = romeo;

    frame = createFrame();

    setLayout(new BoxLayout(this, BoxLayout.LINE_AXIS));

    JPanel leftHalf = new JPanel() {
      //Don't allow us to stretch vertically.
      public Dimension getMaximumSize() {
        Dimension pref = getPreferredSize();
        return new Dimension(Integer.MAX_VALUE, pref.height);
      }
    };
    leftHalf.setLayout(new BoxLayout(leftHalf, BoxLayout.PAGE_AXIS));
    leftHalf.add(createWestPanel());

    add(leftHalf);
    add(createCenterPanel());

    //add(createSouthPanel());

    showFilter();
  }

  /**
   * This method creates a frame for Filter to reside in.
   *
   * @return <code>JFrame</code>
   *
   * @since 0.1.3
   */
  public JFrame createFrame() {
    frame = new JFrame();

    Image icon = Toolkit.getDefaultToolkit().getImage(
                         getClass().getResource(
			 "/images/icons/16x16/Filter.png"));

    frame.setIconImage(icon);

    //frame.addWindowListener(exit);
    return frame;
  }

  /**
   * This method shows the window.
   *
   * @since 0.1.3
   */
  public void showFilter() {
    if(getFrame() != null) {
      // put Downloader in a frame and show it
      JFrame f = getFrame();
      f.setTitle("Romeo: Configure Advanced Filters");
      f.getContentPane().add(this, BorderLayout.CENTER);

      // Set size and location.
      f.pack();
      /*
      f.setResizable(false);
      Dimension screenDim = Toolkit.getDefaultToolkit().getScreenSize();
      Rectangle frameDim = f.getBounds();
      f.setLocation((screenDim.width - frameDim.width) / 2,
                    (screenDim.height - frameDim.height) / 2);

      */

      getFrame().show();
    }
  }

  /**
   * This method returns the frame instance.
   *
   * @return <code>JFrame</code>
   */
  public JFrame getFrame() {
    return frame;
  }

  public JPanel createWestPanel() {
    panel = new JPanel();
    panel.setLayout(new GridLayout(10, 1));

    yearCheckBox         = new JCheckBox();
    yearCheckBox.setText(utils.getString("Table.column_year"));
    yearCheckBox.addItemListener(new ItemListener() {
      public void itemStateChanged(ItemEvent e) {
        if (e.getStateChange() == ItemEvent.SELECTED) {
          lyearCheckBox.setEnabled(true);
          gyearCheckBox.setEnabled(true);
          nyearCheckBox.setEnabled(true);
          eyearCheckBox.setEnabled(true);
          yearList.setEnabled(true);
        }
        else {
          lyearCheckBox.setEnabled(false);
          gyearCheckBox.setEnabled(false);
          nyearCheckBox.setEnabled(false);
          eyearCheckBox.setEnabled(false);
          yearList.setEnabled(false);
        }
      }
    });

    manufacturerCheckBox = new JCheckBox();
    manufacturerCheckBox.setText(utils.getString("Table.column_manufacturer"));

    driverCheckBox       = new JCheckBox();
    driverCheckBox.setText("Driver");

    categoryCheckBox     = new JCheckBox();
    categoryCheckBox.setText(utils.getString("Table.column_category"));

    screenshotCheckBox   = new JCheckBox();
    screenshotCheckBox.setText("Screenshot");

    flyerCheckBox        = new JCheckBox();
    flyerCheckBox.setText("Flyer");

    marqueeCheckBox      = new JCheckBox();
    marqueeCheckBox.setText("Marquee");

    cabinetCheckBox      = new JCheckBox();
    cabinetCheckBox.setText("Cabinet");

    sampleCheckBox       = new JCheckBox();
    sampleCheckBox.setText("Sample");

    artworkCheckBox      = new JCheckBox();
    artworkCheckBox.setText("artwork");

    panel.add(yearCheckBox);
    panel.add(manufacturerCheckBox);
    panel.add(driverCheckBox);
    panel.add(categoryCheckBox);
    panel.add(screenshotCheckBox);
    panel.add(flyerCheckBox);
    panel.add(marqueeCheckBox);
    panel.add(cabinetCheckBox);
    panel.add(sampleCheckBox);
    panel.add(artworkCheckBox);

    return panel;
  }

  /**
   * This method returns a panel.
   *
   * @return <code>JPanel</code>
   *
   * @since 0.1.3
   */
  public JPanel createCenterPanel() {
    panel = new JPanel(new BorderLayout());
    //Lay out the panel.
    panel.setBorder(BorderFactory.createEmptyBorder(
                                GAP/2, //top
                                0,     //left
                                GAP/2, //bottom
                                0));   //right
    panel.add(new JSeparator(JSeparator.VERTICAL), BorderLayout.LINE_START);
    panel.add(createEastPanel(), BorderLayout.CENTER);

    return panel;
  }

  /**
   * This method returns a panel.
   *
   * @return <code>JPanel</code>
   *
   * @since 0.1.3
   */
  public JPanel createEastPanel() {
    panel = new JPanel();
    panel.setLayout(new GridLayout(10, 1));

    panel2 = new JPanel();
    panel2.setLayout(new GridLayout(1, 5));

    lyearCheckBox        = new JCheckBox();
    lyearCheckBox.setText("Less than");
    lyearCheckBox.setEnabled(false);

    gyearCheckBox        = new JCheckBox();
    gyearCheckBox.setText("Greater than");
    gyearCheckBox.setEnabled(false);

    nyearCheckBox        = new JCheckBox();
    nyearCheckBox.setText("Not equal");
    nyearCheckBox.setEnabled(false);

    eyearCheckBox        = new JCheckBox();
    eyearCheckBox.setText("Equal");
    eyearCheckBox.setEnabled(false);

    // Use a list model that allows for updates
    yearModel = new DefaultListModel();

    String year;

    // Add years from 1975 to 2002
    for (int i = 1975; i < 2002; i++) {
      year = i + "";
      yearModel.addElement(year);
    }

    yearList = new JList(yearModel);
    yearList.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);

    JScrollPane p = new JScrollPane(yearList);
    p.setPreferredSize(new Dimension(40, 20));

    panel2.add(lyearCheckBox);
    panel2.add(gyearCheckBox);
    panel2.add(nyearCheckBox);
    panel2.add(eyearCheckBox);
    panel2.add(p);

    panel.add(panel2);

    return panel;
  }

  /**
   * This method returns a panel.
   *
   * @return <code>JPanel</code>
   *
   * @since 0.1.3
   */
  public JPanel createSouthPanel() {
    panel = new JPanel(new FlowLayout(FlowLayout.TRAILING));

    JButton button = new JButton("Set address");
    //button.addActionListener(this);
    panel.add(button);

    button = new JButton("Clear address");
    //button.addActionListener(this);
    //button.setActionCommand("clear");
    panel.add(button);

    // Match the SpringLayout's gap, subtracting 5 to make
    // up for the default gap FlowLayout provides.
    panel.setBorder(BorderFactory.createEmptyBorder(0, 0, GAP - 5, GAP - 5));

    return panel;
  }
}

